==> nomachine-8.7.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/NXSession.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXSession::BEGIN{package NXSession;no warnings;require Common::Logger;do{
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4c\x6f\x67\x67\x65\x72"->import};}package 
NXSession;no warnings;($playerConnected="\x6e\x6f\x74\x53\x65\x74");(
$__sessionType=(""));$__ref_parameters;($sessionCloseStarted=
(0x009c+ 9698-0x267e));sub playerConnectedThroughNXD{Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x70\x6c\x61\x79\x65\x72\x43\x6f\x6e\x6e\x65\x63\x74\x65\x64\x54\x68\x72\x6f\x75\x67\x68\x4e\x58\x44"
);($playerConnected="\x6e\x78\x64");}sub playerConnectedThroughSSHD{
Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x70\x6c\x61\x79\x65\x72\x43\x6f\x6e\x6e\x65\x63\x74\x65\x64\x54\x68\x72\x6f\x75\x67\x68\x53\x53\x48\x44"
);($playerConnected="\x73\x73\x68\x64");}sub playerIsConnected{if ((
$playerConnected eq "\x6e\x6f\x74\x53\x65\x74")){Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x70\x6c\x61\x79\x65\x72\x49\x73\x43\x6f\x6e\x6e\x65\x63\x74\x65\x64\x20\x30"
);return ((0x2041+ 284-0x215d));}Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x70\x6c\x61\x79\x65\x72\x49\x73\x43\x6f\x6e\x6e\x65\x63\x74\x65\x64\x20\x31"
);return ((0x1324+ 700-0x15df));}sub playerIsConnectedThroughNXD{if ((
$playerConnected eq "\x6e\x78\x64")){Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x70\x6c\x61\x79\x65\x72\x49\x73\x43\x6f\x6e\x6e\x65\x63\x74\x65\x64\x54\x68\x72\x6f\x75\x67\x68\x4e\x58\x44\x20\x31"
);return ((0x16ea+ 3089-0x22fa));}Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x70\x6c\x61\x79\x65\x72\x49\x73\x43\x6f\x6e\x6e\x65\x63\x74\x65\x64\x54\x68\x72\x6f\x75\x67\x68\x4e\x58\x44\x20\x30"
);return ((0x0454+ 541-0x0671));}sub playerIsConnectedThroughSSHD{if ((
$playerConnected eq "\x73\x73\x68\x64")){Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x70\x6c\x61\x79\x65\x72\x49\x73\x43\x6f\x6e\x6e\x65\x63\x74\x65\x64\x54\x68\x72\x6f\x75\x67\x68\x53\x53\x48\x44\x20\x31"
);return ((0x08bf+ 4236-0x194a));}Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x70\x6c\x61\x79\x65\x72\x49\x73\x43\x6f\x6e\x6e\x65\x63\x74\x65\x64\x54\x68\x72\x6f\x75\x67\x68\x53\x53\x48\x44\x20\x30"
);return ((0x0950+ 6347-0x221b));}sub addConnectionVariableToEnvironmentArray{(my $ref_array
=shift (@_));(my $nxConnectionEnv=libnxh::NXTransGetEnvironment (
"\x4e\x58\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e"));if (($nxConnectionEnv 
ne (""))){push (@$ref_array,"\x73\x65\x74\x20\x65\x6e\x76",(
"\x4e\x58\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e\x3d".$nxConnectionEnv));
Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x61\x64\x64\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x56\x61\x72\x69\x61\x62\x6c\x65\x54\x6f\x45\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x41\x72\x72\x61\x79\x20\x73\x65\x74\x20\x4e\x58\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e"
);}else{(my $sshConnectionEnv=libnxh::NXTransGetEnvironment (
"\x53\x53\x48\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e"));if ((
$sshConnectionEnv ne (""))){push (@$ref_array,"\x73\x65\x74\x20\x65\x6e\x76",(
"\x53\x53\x48\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e\x3d".$sshConnectionEnv
));Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x61\x64\x64\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x56\x61\x72\x69\x61\x62\x6c\x65\x54\x6f\x45\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x41\x72\x72\x61\x79\x20\x73\x65\x74\x20\x53\x53\x48\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e"
);}(my $sshClientEnv=libnxh::NXTransGetEnvironment (
"\x53\x53\x48\x5f\x43\x4c\x49\x45\x4e\x54"));if (($sshClientEnv ne (""))){push (
@$ref_array,"\x73\x65\x74\x20\x65\x6e\x76",(
"\x53\x53\x48\x5f\x43\x4c\x49\x45\x4e\x54\x3d".$sshClientEnv));Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x61\x64\x64\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x56\x61\x72\x69\x61\x62\x6c\x65\x54\x6f\x45\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x41\x72\x72\x61\x79\x20\x73\x65\x74\x20\x53\x53\x48\x5f\x43\x4c\x49\x45\x4e\x54"
);}}}sub setSessionType{(my $sessionType=shift (@_));($__sessionType=
$sessionType);}sub getSessionType{return ($__sessionType);}sub 
setParametersReference{(my $ref_parameters=shift (@_));($__ref_parameters=
$ref_parameters);}sub getParametersReference{return ($__ref_parameters);}sub 
isRestoreSession{if (($GLOBAL::parameters{
"\x72\x65\x73\x74\x6f\x72\x65\x73\x65\x73\x73\x69\x6f\x6e"}eq "\x31")){return (
(0x1a3f+ 268-0x1b4a));}return ((0x0191+ 181-0x0246));}sub isNotRestoreSession{
return ((!isRestoreSession ()));}sub isFirstAttach{if (($GLOBAL::parameters{
"\x66\x69\x72\x73\x74\x41\x74\x74\x61\x63\x68"}eq "\x31")){return (
(0x0a12+ 1239-0x0ee8));}return ((0x1c2c+ 228-0x1d10));}sub isNotFirstAttach{
return ((!isFirstAttach ()));}sub considerBeforeSessionStart{if ((
isNotRestoreSession ()and isNotFirstAttach ())){NXEvent::beforeSessionStart ();}
}sub considerAfterSessionStart{if ((isNotRestoreSession ()and isNotFirstAttach 
())){NXEvent::afterSessionStart ();}}sub considerBeforeSessionClose{if (((
isNotSessionCloseStarted ()and getSessionType ())and (
Common::NXSessionType::isVirtual (getSessionType ())||
Common::NXSessionType::isAttach (getSessionType ())))){if ((isNotRestoreSession 
()and isNotFirstAttach ())){NXEvent::beforeSessionClose ();}}}sub 
considerAfterSessionClose{if ((getSessionType ()and (
Common::NXSessionType::isVirtual (getSessionType ())||
Common::NXSessionType::isAttach (getSessionType ())))){if ((isNotRestoreSession 
()and isNotFirstAttach ())){NXEvent::afterSessionClose ();}}}sub 
considerAfterSessionFailure{if (((getSessionType ()and 
Common::NXSessionType::isVirtual (getSessionType ()))or 
Common::NXSessionType::isAttach (getSessionType ()))){if ((isNotRestoreSession 
()and isNotFirstAttach ())){NXEvent::afterSessionFailure ();}}}sub 
considerAfterLocalSessionClose{if (Common::NXSessionType::isPhysical (
getSessionType ())){NXEvent::afterLocalSessionClose ();}}sub 
considerAfterLocalSessionFailure{if (Common::NXSessionType::isPhysical (
getSessionType ())){NXEvent::afterLocalSessionFailure ();}}sub 
setSessionCloseStarted{($sessionCloseStarted=(0x06b1+ 5863-0x1d97));}sub 
isSessionCloseStarted{return ($sessionCloseStarted);}sub 
isNotSessionCloseStarted{return ((!isSessionCloseStarted ()));}return (
(0x0769+ 873-0x0ad1));

==> nomachine-8.8.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/NXSession.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXSession::BEGIN{package NXSession;no warnings;require Common::Logger;do{
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4c\x6f\x67\x67\x65\x72"->import};}package 
NXSession;no warnings;($playerConnected="\x6e\x6f\x74\x53\x65\x74");(
$__sessionType=(""));$__ref_parameters;($sessionCloseStarted=
(0x0f6f+ 464-0x113f));sub playerConnectedThroughNXD{Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x70\x6c\x61\x79\x65\x72\x43\x6f\x6e\x6e\x65\x63\x74\x65\x64\x54\x68\x72\x6f\x75\x67\x68\x4e\x58\x44"
);($playerConnected="\x6e\x78\x64");}sub playerConnectedThroughSSHD{
Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x70\x6c\x61\x79\x65\x72\x43\x6f\x6e\x6e\x65\x63\x74\x65\x64\x54\x68\x72\x6f\x75\x67\x68\x53\x53\x48\x44"
);($playerConnected="\x73\x73\x68\x64");}sub playerIsConnected{if ((
$playerConnected eq "\x6e\x6f\x74\x53\x65\x74")){Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x70\x6c\x61\x79\x65\x72\x49\x73\x43\x6f\x6e\x6e\x65\x63\x74\x65\x64\x20\x30"
);return ((0x0efd+ 2084-0x1721));}Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x70\x6c\x61\x79\x65\x72\x49\x73\x43\x6f\x6e\x6e\x65\x63\x74\x65\x64\x20\x31"
);return ((0x06d9+ 6813-0x2175));}sub playerIsConnectedThroughNXD{if ((
$playerConnected eq "\x6e\x78\x64")){Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x70\x6c\x61\x79\x65\x72\x49\x73\x43\x6f\x6e\x6e\x65\x63\x74\x65\x64\x54\x68\x72\x6f\x75\x67\x68\x4e\x58\x44\x20\x31"
);return ((0x0e18+ 1274-0x1311));}Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x70\x6c\x61\x79\x65\x72\x49\x73\x43\x6f\x6e\x6e\x65\x63\x74\x65\x64\x54\x68\x72\x6f\x75\x67\x68\x4e\x58\x44\x20\x30"
);return ((0x085f+ 4209-0x18d0));}sub playerIsConnectedThroughSSHD{if ((
$playerConnected eq "\x73\x73\x68\x64")){Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x70\x6c\x61\x79\x65\x72\x49\x73\x43\x6f\x6e\x6e\x65\x63\x74\x65\x64\x54\x68\x72\x6f\x75\x67\x68\x53\x53\x48\x44\x20\x31"
);return ((0x1136+ 2780-0x1c11));}Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x70\x6c\x61\x79\x65\x72\x49\x73\x43\x6f\x6e\x6e\x65\x63\x74\x65\x64\x54\x68\x72\x6f\x75\x67\x68\x53\x53\x48\x44\x20\x30"
);return ((0x00ed+ 4725-0x1362));}sub addConnectionVariableToEnvironmentArray{(my $ref_array
=shift (@_));(my $nxConnectionEnv=libnxh::NXTransGetEnvironment (
"\x4e\x58\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e"));if (($nxConnectionEnv 
ne (""))){push (@$ref_array,"\x73\x65\x74\x20\x65\x6e\x76",(
"\x4e\x58\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e\x3d".$nxConnectionEnv));
Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x61\x64\x64\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x56\x61\x72\x69\x61\x62\x6c\x65\x54\x6f\x45\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x41\x72\x72\x61\x79\x20\x73\x65\x74\x20\x4e\x58\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e"
);}else{(my $sshConnectionEnv=libnxh::NXTransGetEnvironment (
"\x53\x53\x48\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e"));if ((
$sshConnectionEnv ne (""))){push (@$ref_array,"\x73\x65\x74\x20\x65\x6e\x76",(
"\x53\x53\x48\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e\x3d".$sshConnectionEnv
));Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x61\x64\x64\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x56\x61\x72\x69\x61\x62\x6c\x65\x54\x6f\x45\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x41\x72\x72\x61\x79\x20\x73\x65\x74\x20\x53\x53\x48\x5f\x43\x4f\x4e\x4e\x45\x43\x54\x49\x4f\x4e"
);}(my $sshClientEnv=libnxh::NXTransGetEnvironment (
"\x53\x53\x48\x5f\x43\x4c\x49\x45\x4e\x54"));if (($sshClientEnv ne (""))){push (
@$ref_array,"\x73\x65\x74\x20\x65\x6e\x76",(
"\x53\x53\x48\x5f\x43\x4c\x49\x45\x4e\x54\x3d".$sshClientEnv));Logger::debug (
"\x4e\x58\x53\x65\x73\x73\x69\x6f\x6e\x3a\x3a\x61\x64\x64\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x56\x61\x72\x69\x61\x62\x6c\x65\x54\x6f\x45\x6e\x76\x69\x72\x6f\x6e\x6d\x65\x6e\x74\x41\x72\x72\x61\x79\x20\x73\x65\x74\x20\x53\x53\x48\x5f\x43\x4c\x49\x45\x4e\x54"
);}}}sub setSessionType{(my $sessionType=shift (@_));($__sessionType=
$sessionType);}sub getSessionType{return ($__sessionType);}sub 
setParametersReference{(my $ref_parameters=shift (@_));($__ref_parameters=
$ref_parameters);}sub getParametersReference{return ($__ref_parameters);}sub 
isRestoreSession{if (($GLOBAL::parameters{
"\x72\x65\x73\x74\x6f\x72\x65\x73\x65\x73\x73\x69\x6f\x6e"}eq "\x31")){return (
(0x03a1+ 2914-0x0f02));}return ((0x1705+ 447-0x18c4));}sub isNotRestoreSession{
return ((!isRestoreSession ()));}sub isFirstAttach{if (($GLOBAL::parameters{
"\x66\x69\x72\x73\x74\x41\x74\x74\x61\x63\x68"}eq "\x31")){return (
(0x0c98+ 2812-0x1793));}return ((0x06df+ 6543-0x206e));}sub isNotFirstAttach{
return ((!isFirstAttach ()));}sub considerBeforeSessionStart{if ((
isNotRestoreSession ()and isNotFirstAttach ())){NXEvent::beforeSessionStart ();}
}sub considerAfterSessionStart{if ((isNotRestoreSession ()and isNotFirstAttach 
())){NXEvent::afterSessionStart ();}}sub considerBeforeSessionClose{if (((
isNotSessionCloseStarted ()and getSessionType ())and (
Common::NXSessionType::isVirtual (getSessionType ())||
Common::NXSessionType::isAttach (getSessionType ())))){if ((isNotRestoreSession 
()and isNotFirstAttach ())){NXEvent::beforeSessionClose ();}}}sub 
considerAfterSessionClose{if ((getSessionType ()and (
Common::NXSessionType::isVirtual (getSessionType ())||
Common::NXSessionType::isAttach (getSessionType ())))){if ((isNotRestoreSession 
()and isNotFirstAttach ())){NXEvent::afterSessionClose ();}}}sub 
considerAfterSessionFailure{if (((getSessionType ()and 
Common::NXSessionType::isVirtual (getSessionType ()))or 
Common::NXSessionType::isAttach (getSessionType ()))){if ((isNotRestoreSession 
()and isNotFirstAttach ())){NXEvent::afterSessionFailure ();}}}sub 
considerAfterLocalSessionClose{if (Common::NXSessionType::isPhysical (
getSessionType ())){NXEvent::afterLocalSessionClose ();}}sub 
considerAfterLocalSessionFailure{if (Common::NXSessionType::isPhysical (
getSessionType ())){NXEvent::afterLocalSessionFailure ();}}sub 
setSessionCloseStarted{($sessionCloseStarted=(0x13bd+ 1252-0x18a0));}sub 
isSessionCloseStarted{return ($sessionCloseStarted);}sub 
isNotSessionCloseStarted{return ((!isSessionCloseStarted ()));}return (
(0x0832+ 2089-0x105a));
